@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.14 2002/04/27 14:11:17 joern Exp $
+# $Id: Config.pm,v 1.17 2002/06/09 09:59:28 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -54,6 +54,25 @@ my %CONFIG_PARAMETER = (
 		type => 'file',
 		value => "/dev/dvd",
 	},
+	play_dvd_command => {
+		label => "DVD player command",
+		type  => 'string',
+		value => 'mplayer <dvd://%t -aid 0x8%a -chapter %c -dvdangle %m>',
+		presets => [
+			'mplayer <dvd://%t -aid 0x8%a -chapter %c -dvdangle %m>',
+			'xine -a %a -p <dvdnav://%d:%t.%c>',
+			'xine -a %a -p <d4d://i%tt0c%(%c-1)t%(%c-1)>',
+		],
+	},
+	play_file_command => {
+		label => "File player command",
+		type  => 'string',
+		value => 'xine -p <%f>',
+		presets => [
+			'xine -p <%f>',
+			'mplayer <%f>',
+		],
+	},
 	base_project_dir => {
 		label => "Default Data Base Directory",
 		type => 'dir',
@@ -78,6 +97,7 @@ my %CONFIG_PARAMETER = (
 
 my @CONFIG_ORDER = qw (
 	dvd_device base_project_dir
+	play_dvd_command play_file_command
 	main_window_width main_window_height
 	cluster_master_local cluster_master_server
 	cluster_master_port
@@ -126,365 +146,141 @@ sub new {
 			auto => 1,
 			frame_size => 'small',
 		),
-	);
-
-	if ( $TC::VERSION >= 600 ) {
-		push @presets, (
-			Video::DVDRip::Preset->new (
-				name => "auto_big_fast",
-				title => "Autoadjust, Big Frame, Fast Resize",
-				tc_fast_resize  => 1,
-				auto => 1,
-				frame_size => 'big',
-			),
-			Video::DVDRip::Preset->new (
-				name => "auto_medium_fast",
-				title => "Autoadjust, Medium Frame, Fast Resize",
-				tc_fast_resize  => 1,
-				auto => 1,
-				frame_size => 'medium',
-			),
-			Video::DVDRip::Preset->new (
-				name => "auto_small_fast",
-				title => "Autoadjust, Small Frame, Fast Resize",
-				tc_fast_resize  => 1,
-				auto => 1,
-				frame_size => 'small',
-			),
-		);
-	}
-	
-	push @presets, (
 		Video::DVDRip::Preset->new (
-			name => "169anamorph",
-			title => "16:9 No Letterbox, HQ Resize",
+			name => "auto_big_fast",
+			title => "Autoadjust, Big Frame, Fast Resize",
+			tc_fast_resize  => 1,
+			auto => 1,
+			frame_size => 'big',
+		),
+		Video::DVDRip::Preset->new (
+			name => "auto_medium_fast",
+			title => "Autoadjust, Medium Frame, Fast Resize",
+			tc_fast_resize  => 1,
+			auto => 1,
+			frame_size => 'medium',
+		),
+		Video::DVDRip::Preset->new (
+			name => "auto_small_fast",
+			title => "Autoadjust, Small Frame, Fast Resize",
+			tc_fast_resize  => 1,
+			auto => 1,
+			frame_size => 'small',
+		),
+		Video::DVDRip::Preset->new (
+			name => "vcd_pal_43",
+			title => "VCD 4:3, PAL",
 			tc_clip1_top	=> 0,
 			tc_clip1_bottom	=> 0,
-			tc_clip1_left	=> 0,
-			tc_clip1_right	=> 0,
-			tc_zoom_width	=> 768,
-			tc_zoom_height	=> 432,
+			tc_clip1_left	=> 32,
+			tc_clip1_right	=> 32,
+			tc_zoom_width	=> 352,
+			tc_zoom_height	=> 288,
 			tc_clip2_top	=> 0,
 			tc_clip2_bottom	=> 0,
 			tc_clip2_left	=> 0,
 			tc_clip2_right	=> 0,
-			tc_fast_resize  => 0,
+			tc_fast_resize  => 1,
 			tc_fast_bisection => 0,
 		),
 		Video::DVDRip::Preset->new (
-			name => "169anamorph_letter",
-			title => "16:9 With Letterbox, HQ Resize",
+			name => "vcd_pal_16_9",
+			title => "VCD 16:9, PAL",
+			tc_clip1_top	=> 0,
+			tc_clip1_bottom	=> 0,
+			tc_clip1_left	=> 80,
+			tc_clip1_right	=> 80,
+			tc_zoom_width	=> 352,
+			tc_zoom_height	=> 256,
+			tc_clip2_top	=> -16,
+			tc_clip2_bottom	=> -16,
+			tc_clip2_left	=> 0,
+			tc_clip2_right	=> 0,
+			tc_fast_resize  => 1,
+			tc_fast_bisection => 0,
+		),
+		Video::DVDRip::Preset->new (
+			name => "svcd_pal",
+			title => "SVCD anamorph, PAL",
 			tc_clip1_top	=> 0,
 			tc_clip1_bottom	=> 0,
 			tc_clip1_left	=> 0,
 			tc_clip1_right	=> 0,
-			tc_zoom_width	=> 768,
-			tc_zoom_height	=> 432,
-			tc_clip2_top	=> 56,
-			tc_clip2_bottom	=> 56,
-			tc_clip2_left	=> 64,
-			tc_clip2_right	=> 64,
-			tc_fast_resize  => 0,
-			tc_fast_bisection => 0,
-		),
-	);
-	
-	if ( $TC::VERSION >= 600 ) {
-		push @presets, (
-			Video::DVDRip::Preset->new (
-				name => "169anamorph_fast",
-				title => "16:9 No Letterbox, Fast Resize",
-				tc_clip1_top	=> 4,
-				tc_clip1_bottom	=> 4,
-				tc_clip1_left	=> 0,
-				tc_clip1_right	=> 0,
-				tc_zoom_width	=> 720,
-				tc_zoom_height	=> 400,
-				tc_clip2_top	=> 0,
-				tc_clip2_bottom	=> 0,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-			Video::DVDRip::Preset->new (
-				name => "169anamorph_letter_fast",
-				title => "16:9 Letterbox, Fast Resize",
-				tc_clip1_top	=> 60,
-				tc_clip1_bottom	=> 60,
-				tc_clip1_left	=> 40,
-				tc_clip1_right	=> 40,
-				tc_zoom_width	=> 640,
-				tc_zoom_height	=> 320,
-				tc_clip2_top	=> 0,
-				tc_clip2_bottom	=> 0,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-		);
-	} else {
-		push @presets, (
-			Video::DVDRip::Preset->new (
-				name => "169anamorph_fast",
-				title => "16:9 No Letterbox, Fast Resize",
-				tc_clip1_top	=> 8,
-				tc_clip1_bottom	=> 8,
-				tc_clip1_left	=> 8,
-				tc_clip1_right	=> 8,
-				tc_zoom_width	=> 704,
-				tc_zoom_height	=> 400,
-				tc_clip2_top	=> 0,
-				tc_clip2_bottom	=> 0,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-			Video::DVDRip::Preset->new (
-				name => "169anamorph_letter_fast",
-				title => "16:9 Letterbox, Fast Resize",
-				tc_clip1_top	=> 64,
-				tc_clip1_bottom	=> 64,
-				tc_clip1_left	=> 40,
-				tc_clip1_right	=> 40,
-				tc_zoom_width	=> 640,
-				tc_zoom_height	=> 320,
-				tc_clip2_top	=> 0,
-				tc_clip2_bottom	=> 0,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-		);
-	}
-	
-	push @presets, (
-		Video::DVDRip::Preset->new (
-			name => "43nothing",
-			title => "4:3 No Letterbox, HQ Resize",
-			tc_clip1_top	=> 0,
-			tc_clip1_bottom	=> 0,
-			tc_clip1_left	=> 0,
-			tc_clip1_right	=> 0,
-			tc_zoom_width	=> 720,
-			tc_zoom_height	=> 544,
+			tc_zoom_width	=> 480,
+			tc_zoom_height	=> 576,
 			tc_clip2_top	=> 0,
 			tc_clip2_bottom	=> 0,
 			tc_clip2_left	=> 0,
 			tc_clip2_right	=> 0,
-			tc_fast_resize  => 0,
+			tc_fast_resize  => 1,
 			tc_fast_bisection => 0,
 		),
 		Video::DVDRip::Preset->new (
-			name => "43letter_clip",
-			title => "4:3 Letterbox, HQ Resize",
-			tc_clip1_top	=> 80,
-			tc_clip1_bottom	=> 80,
+			name => "vcd_ntsc_43",
+			title => "VCD 4:3, NTSC",
+			tc_clip1_top	=> 20,
+			tc_clip1_bottom	=> 20,
+			tc_clip1_left	=> 0,
+			tc_clip1_right	=> 0,
+			tc_zoom_width	=> 352,
+			tc_zoom_height	=> 240,
+			tc_clip2_top	=> 0,
+			tc_clip2_bottom	=> 0,
+			tc_clip2_left	=> 0,
+			tc_clip2_right	=> 0,
+			tc_fast_resize  => 1,
+			tc_fast_bisection => 0,
+		),
+		Video::DVDRip::Preset->new (
+			name => "vcd_ntsc_16_9",
+			title => "VCD 16:9, NTSC",
+			tc_clip1_top	=> 0,
+			tc_clip1_bottom	=> 0,
 			tc_clip1_left	=> 16,
 			tc_clip1_right	=> 16,
-			tc_zoom_width	=> 688,
-			tc_zoom_height	=> 392,
-			tc_clip2_top	=> 4,
-			tc_clip2_bottom	=> 4,
+			tc_zoom_width	=> 352,
+			tc_zoom_height	=> 208,
+			tc_clip2_top	=> -16,
+			tc_clip2_bottom	=> -16,
 			tc_clip2_left	=> 0,
 			tc_clip2_right	=> 0,
-			tc_fast_resize  => 0,
+			tc_fast_resize  => 1,
 			tc_fast_bisection => 0,
 		),
+		Video::DVDRip::Preset->new (
+			name => "svcd_ntsc",
+			title => "SVCD anamorph, NTSC",
+			tc_clip1_top	=> 0,
+			tc_clip1_bottom	=> 0,
+			tc_clip1_left	=> 0,
+			tc_clip1_right	=> 0,
+			tc_zoom_width	=> 480,
+			tc_zoom_height	=> 480,
+			tc_clip2_top	=> 0,
+			tc_clip2_bottom	=> 0,
+			tc_clip2_left	=> 0,
+			tc_clip2_right	=> 0,
+			tc_fast_resize  => 1,
+			tc_fast_bisection => 0,
+		),
+#		Video::DVDRip::Preset->new (
+#			name => "fast_bisection",
+#			title => "Fast Frame Bisection",
+#			tc_clip1_top	=> 0,
+#			tc_clip1_bottom	=> 0,
+#			tc_clip1_left	=> 0,
+#			tc_clip1_right	=> 0,
+#			tc_zoom_width	=> undef,
+#			tc_zoom_height	=> undef,
+#			tc_clip2_top	=> 0,
+#			tc_clip2_bottom	=> 0,
+#			tc_clip2_left	=> 0,
+#			tc_clip2_right	=> 0,
+#			tc_fast_resize  => 0,
+#			tc_fast_bisection => 1,
+#		),
 	);
 
-	if ( $TC::VERSION >= 600 ) {
-		push @presets, (
-			Video::DVDRip::Preset->new (
-				name => "43nothing_fast",
-				title => "4:3 No Letterbox, Fast Resize",
-				tc_clip1_top	=> 0,
-				tc_clip1_bottom	=> 0,
-				tc_clip1_left	=> 0,
-				tc_clip1_right	=> 0,
-				tc_zoom_width	=> 704,
-				tc_zoom_height	=> 528,
-				tc_clip2_top	=> 4,
-				tc_clip2_bottom	=> 4,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-			Video::DVDRip::Preset->new (
-				name => "43letter_clip_fast",
-				title => "4:3 Letterbox, Fast Resize",
-				tc_clip1_top	=> 80,
-				tc_clip1_bottom	=> 80,
-				tc_clip1_left	=> 16,
-				tc_clip1_right	=> 16,
-				tc_zoom_width	=> 688,
-				tc_zoom_height	=> 392,
-				tc_clip2_top	=> 4,
-				tc_clip2_bottom	=> 4,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-		);
-	} else {
-		push @presets, (
-			Video::DVDRip::Preset->new (
-				name => "43nothing_fast",
-				title => "4:3 No Letterbox, Fast Resize",
-				tc_clip1_top	=> 0,
-				tc_clip1_bottom	=> 0,
-				tc_clip1_left	=> 8,
-				tc_clip1_right	=> 8,
-				tc_zoom_width	=> 704,
-				tc_zoom_height	=> 544,
-				tc_clip2_top	=> 0,
-				tc_clip2_bottom	=> 0,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-			Video::DVDRip::Preset->new (
-				name => "43letter_clip_fast",
-				title => "4:3 Letterbox, Fast Resize",
-				tc_clip1_top	=> 80,
-				tc_clip1_bottom	=> 80,
-				tc_clip1_left	=> 16,
-				tc_clip1_right	=> 16,
-				tc_zoom_width	=> 688,
-				tc_zoom_height	=> 384,
-				tc_clip2_top	=> 0,
-				tc_clip2_bottom	=> 0,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-		);
-	}
-	
-	if ( $TC::VERSION >= 600 ) {
-		push @presets, (
-			Video::DVDRip::Preset->new (
-				name => "vcd_pal_43",
-				title => "VCD 4:3, PAL",
-				tc_clip1_top	=> 0,
-				tc_clip1_bottom	=> 0,
-				tc_clip1_left	=> 32,
-				tc_clip1_right	=> 32,
-				tc_zoom_width	=> 352,
-				tc_zoom_height	=> 288,
-				tc_clip2_top	=> 0,
-				tc_clip2_bottom	=> 0,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-			Video::DVDRip::Preset->new (
-				name => "vcd_pal_16_9",
-				title => "VCD 16:9, PAL",
-				tc_clip1_top	=> 0,
-				tc_clip1_bottom	=> 0,
-				tc_clip1_left	=> 80,
-				tc_clip1_right	=> 80,
-				tc_zoom_width	=> 352,
-				tc_zoom_height	=> 256,
-				tc_clip2_top	=> -16,
-				tc_clip2_bottom	=> -16,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-			Video::DVDRip::Preset->new (
-				name => "svcd_pal",
-				title => "SVCD anamorph, PAL",
-				tc_clip1_top	=> 0,
-				tc_clip1_bottom	=> 0,
-				tc_clip1_left	=> 0,
-				tc_clip1_right	=> 0,
-				tc_zoom_width	=> 480,
-				tc_zoom_height	=> 576,
-				tc_clip2_top	=> 0,
-				tc_clip2_bottom	=> 0,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-			Video::DVDRip::Preset->new (
-				name => "vcd_ntsc_43",
-				title => "VCD 4:3, NTSC",
-				tc_clip1_top	=> 20,
-				tc_clip1_bottom	=> 20,
-				tc_clip1_left	=> 0,
-				tc_clip1_right	=> 0,
-				tc_zoom_width	=> 352,
-				tc_zoom_height	=> 240,
-				tc_clip2_top	=> 0,
-				tc_clip2_bottom	=> 0,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-			Video::DVDRip::Preset->new (
-				name => "vcd_ntsc_16_9",
-				title => "VCD 16:9, NTSC",
-				tc_clip1_top	=> 0,
-				tc_clip1_bottom	=> 0,
-				tc_clip1_left	=> 16,
-				tc_clip1_right	=> 16,
-				tc_zoom_width	=> 352,
-				tc_zoom_height	=> 208,
-				tc_clip2_top	=> -16,
-				tc_clip2_bottom	=> -16,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-			Video::DVDRip::Preset->new (
-				name => "svcd_ntsc",
-				title => "SVCD anamorph, NTSC",
-				tc_clip1_top	=> 0,
-				tc_clip1_bottom	=> 0,
-				tc_clip1_left	=> 0,
-				tc_clip1_right	=> 0,
-				tc_zoom_width	=> 480,
-				tc_zoom_height	=> 480,
-				tc_clip2_top	=> 0,
-				tc_clip2_bottom	=> 0,
-				tc_clip2_left	=> 0,
-				tc_clip2_right	=> 0,
-				tc_fast_resize  => 1,
-				tc_fast_bisection => 0,
-			),
-#			Video::DVDRip::Preset->new (
-#				name => "fast_bisection",
-#				title => "Fast Frame Bisection",
-#				tc_clip1_top	=> 0,
-#				tc_clip1_bottom	=> 0,
-#				tc_clip1_left	=> 0,
-#				tc_clip1_right	=> 0,
-#				tc_zoom_width	=> undef,
-#				tc_zoom_height	=> undef,
-#				tc_clip2_top	=> 0,
-#				tc_clip2_bottom	=> 0,
-#				tc_clip2_left	=> 0,
-#				tc_clip2_right	=> 0,
-#				tc_fast_resize  => 0,
-#				tc_fast_bisection => 1,
-#			),
-		);
-	}
-
 	my $self = {
 		config => \%config_parameter,
 		order  => \@config_order,
@@ -541,7 +337,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or confess "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.14 2002/04/27 14:11:17 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.17 2002/06/09 09:59:28 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
@@ -631,3 +427,134 @@ sub get_preset {
 }
 
 1;
+
+__END__
+
+		Video::DVDRip::Preset->new (
+			name => "169anamorph",
+			title => "16:9 No Letterbox, HQ Resize",
+			tc_clip1_top	=> 0,
+			tc_clip1_bottom	=> 0,
+			tc_clip1_left	=> 0,
+			tc_clip1_right	=> 0,
+			tc_zoom_width	=> 768,
+			tc_zoom_height	=> 432,
+			tc_clip2_top	=> 0,
+			tc_clip2_bottom	=> 0,
+			tc_clip2_left	=> 0,
+			tc_clip2_right	=> 0,
+			tc_fast_resize  => 0,
+			tc_fast_bisection => 0,
+		),
+		Video::DVDRip::Preset->new (
+			name => "169anamorph_letter",
+			title => "16:9 With Letterbox, HQ Resize",
+			tc_clip1_top	=> 0,
+			tc_clip1_bottom	=> 0,
+			tc_clip1_left	=> 0,
+			tc_clip1_right	=> 0,
+			tc_zoom_width	=> 768,
+			tc_zoom_height	=> 432,
+			tc_clip2_top	=> 56,
+			tc_clip2_bottom	=> 56,
+			tc_clip2_left	=> 64,
+			tc_clip2_right	=> 64,
+			tc_fast_resize  => 0,
+			tc_fast_bisection => 0,
+		),
+		Video::DVDRip::Preset->new (
+			name => "169anamorph_fast",
+			title => "16:9 No Letterbox, Fast Resize",
+			tc_clip1_top	=> 4,
+			tc_clip1_bottom	=> 4,
+			tc_clip1_left	=> 0,
+			tc_clip1_right	=> 0,
+			tc_zoom_width	=> 720,
+			tc_zoom_height	=> 400,
+			tc_clip2_top	=> 0,
+			tc_clip2_bottom	=> 0,
+			tc_clip2_left	=> 0,
+			tc_clip2_right	=> 0,
+			tc_fast_resize  => 1,
+			tc_fast_bisection => 0,
+		),
+		Video::DVDRip::Preset->new (
+			name => "169anamorph_letter_fast",
+			title => "16:9 Letterbox, Fast Resize",
+			tc_clip1_top	=> 60,
+			tc_clip1_bottom	=> 60,
+			tc_clip1_left	=> 40,
+			tc_clip1_right	=> 40,
+			tc_zoom_width	=> 640,
+			tc_zoom_height	=> 320,
+			tc_clip2_top	=> 0,
+			tc_clip2_bottom	=> 0,
+			tc_clip2_left	=> 0,
+			tc_clip2_right	=> 0,
+			tc_fast_resize  => 1,
+			tc_fast_bisection => 0,
+		),
+		Video::DVDRip::Preset->new (
+			name => "43nothing",
+			title => "4:3 No Letterbox, HQ Resize",
+			tc_clip1_top	=> 0,
+			tc_clip1_bottom	=> 0,
+			tc_clip1_left	=> 0,
+			tc_clip1_right	=> 0,
+			tc_zoom_width	=> 720,
+			tc_zoom_height	=> 544,
+			tc_clip2_top	=> 0,
+			tc_clip2_bottom	=> 0,
+			tc_clip2_left	=> 0,
+			tc_clip2_right	=> 0,
+			tc_fast_resize  => 0,
+			tc_fast_bisection => 0,
+		),
+		Video::DVDRip::Preset->new (
+			name => "43letter_clip",
+			title => "4:3 Letterbox, HQ Resize",
+			tc_clip1_top	=> 80,
+			tc_clip1_bottom	=> 80,
+			tc_clip1_left	=> 16,
+			tc_clip1_right	=> 16,
+			tc_zoom_width	=> 688,
+			tc_zoom_height	=> 392,
+			tc_clip2_top	=> 4,
+			tc_clip2_bottom	=> 4,
+			tc_clip2_left	=> 0,
+			tc_clip2_right	=> 0,
+			tc_fast_resize  => 0,
+			tc_fast_bisection => 0,
+		),
+		Video::DVDRip::Preset->new (
+			name => "43nothing_fast",
+			title => "4:3 No Letterbox, Fast Resize",
+			tc_clip1_top	=> 0,
+			tc_clip1_bottom	=> 0,
+			tc_clip1_left	=> 0,
+			tc_clip1_right	=> 0,
+			tc_zoom_width	=> 704,
+			tc_zoom_height	=> 528,
+			tc_clip2_top	=> 4,
+			tc_clip2_bottom	=> 4,
+			tc_clip2_left	=> 0,
+			tc_clip2_right	=> 0,
+			tc_fast_resize  => 1,
+			tc_fast_bisection => 0,
+		),
+		Video::DVDRip::Preset->new (
+			name => "43letter_clip_fast",
+			title => "4:3 Letterbox, Fast Resize",
+			tc_clip1_top	=> 80,
+			tc_clip1_bottom	=> 80,
+			tc_clip1_left	=> 16,
+			tc_clip1_right	=> 16,
+			tc_zoom_width	=> 688,
+			tc_zoom_height	=> 392,
+			tc_clip2_top	=> 4,
+			tc_clip2_bottom	=> 4,
+			tc_clip2_left	=> 0,
+			tc_clip2_right	=> 0,
+			tc_fast_resize  => 1,
+			tc_fast_bisection => 0,
+		),
