@@ -1,15 +1,13 @@
-# $Id: PSU.pm,v 1.7 2006/05/15 20:27:16 joern Exp $
+# $Id: PSU.pm,v 1.1 2002/02/11 17:10:31 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
-# All Rights Reserved. See file COPYRIGHT for details.
-#
+# Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
+# 
 # This program is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::PSU;
-use Locale::TextDomain qw (video.dvdrip);
 
 use base Video::DVDRip::Base;
 
@@ -23,16 +21,17 @@ sub set_nr			{ shift->{nr}			= $_[1] }
 sub set_frames			{ shift->{frames}		= $_[1]	}
 
 sub new {
-    my $class = shift;
-    my %par   = @_;
-    my ( $nr, $frames ) = @par{ 'nr', 'frames' };
+	my $class = shift;
+	my %par = @_;
+	my  ($nr, $frames) =
+	@par{'nr','frames'};
 
-    my $self = bless {
-        nr     => $nr,
-        frames => $frames,
-    }, $class;
-
-    return $self;
+	my $self = bless {
+		nr	 => $nr,
+		frames	 => $frames,
+	}, $class;
+	
+	return $self;
 }
 
 1;
