@@ -1,16 +1,13 @@
-# $Id: Message.pm,v 1.8 2005/12/26 13:57:47 joern Exp $
+# $Id: Message.pm,v 1.2 2002/02/17 14:23:01 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
-# All Rights Reserved. See file COPYRIGHT for details.
+# Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
 # 
 # This module is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::RPC::Message;
-use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use base Video::DVDRip::Base;
 
@@ -22,7 +19,7 @@ sub pack {
 	my $class = shift;
 	my ($ref) = @_;
 
-	my $packed = Storable::nfreeze ($ref);
+	my $packed = Storable::freeze ($ref);
 
 	$packed =~ s/\\/\\\\/g;
 	$packed =~ s/\n/\\n/g;
@@ -43,3 +40,4 @@ sub unpack {
 }
 
 1;
+
